import test from 'ava'
import { Caller, CallCenter, Receptionist } from '../call-center/index.mjs'

test('caller calls in and is put in a queue', (t) => {
  const center = new CallCenter()
  const caller = new Caller(12345678)
  center.callerCalling(caller)
  t.is(center.isQueued(caller), true, 'caller was not queued')
})

test('receptionists can come and leave work', (t) => {
  const center = new CallCenter()
  const receptionist1 = new Receptionist()
  const receptionist2 = new Receptionist()
  center.receptionistSigningIn(receptionist1)
  center.receptionistSigningIn(receptionist2)
  t.is(center.receptionists.length, 2)
  center.receptionistSigningOff(receptionist1)
  t.is(center.receptionists.length, 1)
})

test('callers are handled in turn by receptionist', (t) => {
  const center = new CallCenter()
  const caller1 = new Caller(12345678)
  const caller2 = new Caller(32145677)
  center.callerCalling(caller1)
  center.callerCalling(caller2)
  const receptionist = new Receptionist()
  center.receptionistSigningIn(receptionist)
  center.handleCaller()
  t.true(
    receptionist.talkingTo === caller1,
    'receptionist was not talking to correct caller'
  )
})

test('lunch break puts all callers back in the queue', (t) => {
  const center = new CallCenter()
  const caller1 = new Caller(12345678)
  const caller2 = new Caller(32145677)
  center.callerCalling(caller1)
  center.callerCalling(caller2)
  const receptionist = new Receptionist()
  center.receptionistSigningIn(receptionist)
  center.handleCaller()
  t.false(center.isQueued(caller1), 'caller should not be queued')
  center.lunchbreak()
  t.true(center.isQueued(caller1), 'caller was not back in queue')
})

// Lunch break will put callers back to wo
